@@ -121,7 +121,7 @@ def curses_main_v2(stdscr):
             jobs = mini.LsJobs
             mini.Upcfg(cfg.scheduling, cfg.plotting)
             if plotting_active:
-                mini.ParallelWorker(cfg.scheduling, cfg.directories)
+                mini.ParallelWorker()
                 aging_reason = mini.wait_reason
                 log.log(aging_reason)
 
