@@ -96,18 +96,18 @@ def plotting(cfg: PlotmanConfig):
     minp.PlotDaemon()
     while True:
         try:
+            print(f"s{cfg.scheduling.polling_time_s}\n")
+            time.sleep(cfg.scheduling.polling_time_s)
+
             minp.GenJobs(cfg.directories)
             minp.Upcfg(cfg.scheduling, cfg.plotting)
 
             if minp.isCreateNewJobParallelReady:
-                minp.ParallelWorker(cfg.scheduling, cfg.directories)
+                minp.ParallelWorker()
 
             if cfg.apis.target is not "":
                 PostDat(minp.GenStatus(minp.LsJobs), cfg)
 
-            print(f"s{cfg.scheduling.polling_time_s}\n")
-            time.sleep(cfg.scheduling.polling_time_s)
-
         except ValidationError as te:
             print('got ConfigurationException from io', te)
             continue
@@ -124,6 +124,7 @@ def plotting(cfg: PlotmanConfig):
             print('got IOError from io', io)
             continue
 
+
     print('exit from error unknown...')
 
 
